{% extends "mfa_auth_base.html" %}
{% block head %}
{% endblock %}
{% block content %}
    <br/>
<br/>
<div class="row">

<div class="col-sm-10 col-sm-offset-1 col-xs-12 col-md-10 col-md-offset-1 col-lg-8 col-lg-offset-2">
<div class="panel panel-default">
      <div class="panel-heading">
	      <strong> Add Trusted Device</strong>
      </div>
      <div class="panel-body">
            <div class="alert alert-success">
                Your device is now trusted, please try to <a href="{{ HOST }}{{ BASE_URL }}accounts/login/"> login</a>
            </div>

	      </div>
	      <div class="panel-footer ">


	      </div>
              </div>
	      </div>
	      </div>


  {% endblock %}
